@@ -1,10 +1,10 @@
 from monday.query_joins import (
     create_board_by_workspace_query,
-    get_board_items_query,
+    get_board_items_by_id_query, get_board_items_query,
     get_boards_by_id_query,
     get_boards_query,
     get_columns_by_board_query,
-    get_board_activity_query,
+    get_board_activity_query, get_paginated_board_items_query,
 )
 from monday.resources.base import BaseResource
 
@@ -25,6 +25,14 @@ class BoardResource(BaseResource):
         query = get_board_items_query(board_ids)
         return self.client.execute(query)
 
+    def fetch_paginated_items_by_board_id(self, board_ids, page, limit):
+        query = get_paginated_board_items_query(board_ids, page, limit)
+        return self.client.execute(query)
+
+    def fetch_items_by_board_id_and_item_id(self, board_ids, item_id):
+        query = get_board_items_by_id_query(board_ids, item_id)
+        return self.client.execute(query)
+
     def fetch_columns_by_board_id(self, board_ids):
         query = get_columns_by_board_query(board_ids)
         return self.client.execute(query)
